nvector._core.n_EA_E_and_p_AB_E2n_EB_E — nvector 0.7.5 documentation

# nvector._core.n_EA_E_and_p_AB_E2n_EB_E

`n_EA_E_and_p_AB_E2n_EB_E`(n_EA_E, p_AB_E, z_EA=0, a=6378137, f=0.0033528106647474805, R_Ee=None)

  Returns position B from position A and delta.

  Parameters
    n_EA_E: 3 x n array

      n-vector(s) [no unit] of position A, decomposed in E.

    p_AB_E: 3 x n array

      Cartesian position vector(s) from A to B, decomposed in E.

    z_EA: 1 x n array

      Depth(s) [m] of system A, relative to the ellipsoid. (z_EA = -height)

    a: real scalar, default WGS-84 ellipsoid.

      Semi-major axis of the Earth ellipsoid given in [m].

    f: real scalar, default WGS-84 ellipsoid.

      Flattening [no unit] of the Earth ellipsoid. If f==0 then spherical Earth with radius a is used in stead of WGS-84.

    R_Ee3 x 3 array

      rotation matrix defining the axes of the coordinate frame E.

  Returns
    n_EB_E: 3 x n array

      n-vector(s) [no unit] of position B, decomposed in E.

    z_EB: 1 x n array

      Depth(s) [m] of system B, relative to the ellipsoid. (z_EB = -height)

  See also

  `n_EA_E_and_n_EB_E2p_AB_E`, `p_EB_E2n_EB_E`, `n_EB_E2p_EB_E`

  Notes

  The n-vector for position A (n_EA_E) and the position-vector from position A to position B (p_AB_E) are given. The output is the n-vector of position B (n_EB_E) and depth of B (z_EB). The calculation is excact, taking the ellipsity of the Earth into account. It is also non-singular as both n-vector and p-vector are non-singular (except for the center of the Earth). The default ellipsoid model used is WGS-84, but other ellipsoids/spheres might be specified.